@@ -49,7 +49,7 @@ openbugs <- function(data, inits, parameters.to.save, model.file="model.txt",
     try(file.copy(file.path(savedWD, data), data, overwrite = TRUE))
   BRugs::modelData(data)
   BRugs::modelCompile(numChains)
-  if(!is.null(seed)) BRugs::modelSetSeed(newSeed=seed)
+  if(!is.null(seed)) BRugs::modelSetRN(seed)
   if(missing(inits) || is.null(inits)) {
     BRugs::modelGenInits()
   } else {
@@ -66,7 +66,7 @@ openbugs <- function(data, inits, parameters.to.save, model.file="model.txt",
   BRugs::samplesSetThin(nThin)
   ## set the adaptive phases
 
-## We do no longer have any Registry.txt file availabe, 
+## We do no longer have any Registry.txt file availabe,
 ## hence not resetting the adaptive phase any more.
 ## People should move to BRugs directly.
 #  adaptivelines <- scan(system.file("OpenBUGS", "Bugs", "Rsrc",
@@ -75,7 +75,7 @@ openbugs <- function(data, inits, parameters.to.save, model.file="model.txt",
 #  factories <- sub(".adaptivePhase", "",
 #                   adaptivelines[grep("adaptivePhase",adaptivelines)])
 #  sapply(factories, BRugs::modelSetAP, max(0, nBurnin-1))
-  if(getOption("BRugsVerbose")){   
+  if(getOption("BRugsVerbose")){
     cat("Sampling has been started ...\n")
     flush.console()
   }
